@@ -5,9 +5,11 @@ static SDL_Joystick *joy=NULL;
 
 void JoystickInit()
 {
-        /* XXX: Should check to see how many joysticks there are (if any),
-          how many buttons they have, etc. */
-        joy = SDL_JoystickOpen(0);
+    puts("** Init joystick **");
+    if ( SDL_Init(SDL_INIT_JOYSTICK ) < 0 ) ComplainAndExit();
+    /* XXX: Should check to see how many joysticks there are (if any),
+        how many buttons they have, etc. */
+    joy = SDL_JoystickOpen(0);
 }
 
 /* Joystick moves the mouse. */
